@@ -1,7 +1,7 @@
 package Perinci::CmdLine::dux;
 
-our $DATE = '2015-11-22'; # DATE
-our $VERSION = '1.51'; # VERSION
+our $DATE = '2016-04-27'; # DATE
+our $VERSION = '1.52'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -90,11 +90,17 @@ sub hook_display_result {
 
     my $res = $r->{res};
     my $x = $r->{args}{out};
-    my $i = 0;
-    while (~~(@$x) > 0) {
-        $log->tracef("[pericmd] Running hook_format_row ...") unless $i;
-        $i++;
-        print $self->hook_format_row($r, shift(@$x));
+
+    if ($x) {
+        # we only set 'out' for action=call, not for other actions
+        my $i = 0;
+        while (~~(@$x) > 0) {
+            $log->tracef("[pericmd] Running hook_format_row ...") unless $i;
+            $i++;
+            print $self->hook_format_row($r, shift(@$x));
+        }
+    } else {
+        print $r->{fres};
     }
 }
 
@@ -113,7 +119,7 @@ Perinci::CmdLine::dux - Perinci::CmdLine subclass for dux cli
 
 =head1 VERSION
 
-This document describes version 1.51 of Perinci::CmdLine::dux (from Perl distribution App-dux), released on 2015-11-22.
+This document describes version 1.52 of Perinci::CmdLine::dux (from Perl distribution App-dux), released on 2016-04-27.
 
 =head1 DESCRIPTION
 
@@ -125,10 +131,6 @@ function is aware it is being run through the dux CLI application.
 
 =for Pod::Coverage .+
 
-=head1 SEE ALSO
-
-L<Perinci::CmdLine>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-dux>.
@@ -145,13 +147,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci::CmdLine>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
